Command line programs
=====================

Paraphernalia ships with a few command line programs. These are self-documenting
via the ``--help`` option.

.. click:: paraphernalia.glsl:render
   :prog: render
   :nested: full

.. click:: paraphernalia.glsl:preview
   :prog: preview
   :nested: full

.. click:: paraphernalia.review:review
   :prog: review
   :nested: full

.. click:: paraphernalia.signature:sign
   :prog: sign
   :nested: full
